You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafficserver.apache.org by rr...@apache.org on 2019/04/30 03:06:20 UTC

[trafficserver] branch master updated: fixes spelling in include

This is an automated email from the ASF dual-hosted git repository.

rrm pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/trafficserver.git


The following commit(s) were added to refs/heads/master by this push:
     new 774f55f  fixes spelling in include
774f55f is described below

commit 774f55f107bee5316b152afc12b70c59dcb333f3
Author: Randall Meyer <ra...@yahoo.com>
AuthorDate: Thu Apr 25 16:27:28 2019 +0800

    fixes spelling in include
---
 include/ts/TsException.h                      |  2 +-
 include/ts/experimental.h                     |  4 ++--
 include/ts/remap.h                            | 10 +++++-----
 include/ts/ts.h                               | 18 +++++++++---------
 include/tscore/AcidPtr.h                      |  4 ++--
 include/tscore/Allocator.h                    |  2 +-
 include/tscore/ArgParser.h                    |  4 ++--
 include/tscore/AtomicBit.h                    |  2 +-
 include/tscore/BufferWriter.h                 | 22 +++++++++++-----------
 include/tscore/BufferWriterForward.h          |  2 +-
 include/tscore/CryptoHash.h                   |  2 +-
 include/tscore/Extendible.h                   |  6 +++---
 include/tscore/HostLookup.h                   |  2 +-
 include/tscore/I_Layout.h                     |  2 +-
 include/tscore/IntrusiveHashMap.h             |  2 +-
 include/tscore/IpMap.h                        |  4 ++--
 include/tscore/MemArena.h                     |  2 +-
 include/tscore/ParseRules.h                   |  4 ++--
 include/tscore/Ptr.h                          |  2 +-
 include/tscore/Scalar.h                       |  4 ++--
 include/tscore/SimpleTokenizer.h              |  2 +-
 include/tscore/TextBuffer.h                   |  2 +-
 include/tscore/Tokenizer.h                    | 12 ++++++------
 include/tscore/ink_base64.h                   |  2 +-
 include/tscore/ink_cap.h                      |  2 +-
 include/tscore/ink_code.h                     |  2 +-
 include/tscore/ink_endian.h                   |  2 +-
 include/tscore/ink_file.h                     |  2 +-
 include/tscore/ink_hrtime.h                   |  4 ++--
 include/tscore/ink_inet.h                     |  2 +-
 include/tscore/ink_lockfile.h                 |  2 +-
 include/tscore/ink_resolver.h                 |  4 ++--
 include/tscore/signals.h                      |  2 +-
 include/tscpp/api/Continuation.h              |  4 ++--
 include/tscpp/api/GlobalPlugin.h              |  6 +++---
 include/tscpp/api/GzipDeflateTransformation.h |  6 +++---
 include/tscpp/api/GzipInflateTransformation.h |  8 ++++----
 include/tscpp/api/Headers.h                   | 14 +++++++-------
 include/tscpp/api/Logger.h                    |  8 ++++----
 include/tscpp/api/Plugin.h                    |  8 ++++----
 include/tscpp/api/RemapPlugin.h               |  2 +-
 include/tscpp/api/Stat.h                      |  2 +-
 include/tscpp/api/Transaction.h               |  6 +++---
 include/tscpp/api/TransactionPlugin.h         |  8 ++++----
 include/tscpp/api/TransformationPlugin.h      |  4 ++--
 include/tscpp/api/noncopyable.h               |  2 +-
 include/tscpp/util/IntrusiveDList.h           | 12 ++++++------
 include/tscpp/util/MemSpan.h                  |  4 ++--
 include/tscpp/util/TextView.h                 | 12 ++++++------
 include/wccp/Wccp.h                           |  2 +-
 50 files changed, 124 insertions(+), 124 deletions(-)

diff --git a/include/ts/TsException.h b/include/ts/TsException.h
index ca833d0..ff80894 100644
--- a/include/ts/TsException.h
+++ b/include/ts/TsException.h
@@ -35,7 +35,7 @@ namespace ts
 /** Base class for ATS exception.
     Clients should subclass as appropriate. This is intended to carry
     pre-allocated text along so that it can be thrown without any
-    addditional memory allocation.
+    additional memory allocation.
 */
 class Exception
 {
diff --git a/include/ts/experimental.h b/include/ts/experimental.h
index 8f9a818..fa8e7ea 100644
--- a/include/ts/experimental.h
+++ b/include/ts/experimental.h
@@ -192,7 +192,7 @@ tsapi TSReturnCode TSHttpTxnInfoIntGet(TSHttpTxn txnp, TSHttpTxnInfoKey key, TSM
 
 /****************************************************************************
  *  TSHttpTxnCacheLookupCountGet
- *  Return: TS_SUCESS/TS_ERROR
+ *  Return: TS_SUCCESS/TS_ERROR
  ****************************************************************************/
 tsapi TSReturnCode TSHttpTxnCacheLookupCountGet(TSHttpTxn txnp, int *lookup_count);
 tsapi TSReturnCode TSHttpTxnServerRespIgnore(TSHttpTxn txnp);
@@ -390,7 +390,7 @@ tsapi void TSFetchWriteData(TSFetchSM fetch_sm, const void *data, size_t len);
 tsapi ssize_t TSFetchReadData(TSFetchSM fetch_sm, void *buf, size_t len);
 
 /*
- * Lanuch FetchSM to do http request, before calling this API,
+ * Launch FetchSM to do http request, before calling this API,
  * you should append http request header into fetch sm through
  * TSFetchWriteData() API
  *
diff --git a/include/ts/ts.h b/include/ts/ts.h
index b156414..55bae84 100644
--- a/include/ts/ts.h
+++ b/include/ts/ts.h
@@ -1309,7 +1309,7 @@ tsapi TSReturnCode TSHttpTxnCacheLookupStatusGet(TSHttpTxn txnp, int *lookup_sta
 tsapi TSReturnCode TSHttpTxnTransformRespGet(TSHttpTxn txnp, TSMBuffer *bufp, TSMLoc *offset);
 
 /** Set the @a port value for the inbound (user agent) connection in the transaction @a txnp.
-    This is used primarily where the conection is synthetic and therefore does not have a port.
+    This is used primarily where the connection is synthetic and therefore does not have a port.
     @note @a port is in @b host @b order.
 */
 tsapi void TSHttpTxnClientIncomingPortSet(TSHttpTxn txnp, int port);
@@ -1452,8 +1452,8 @@ tsapi TSReturnCode TSHttpTxnServerPacketDscpSet(TSHttpTxn txnp, int dscp);
 /**
    Sets an error type body to a transaction. Note that both string arguments
    must be allocated with TSmalloc() or TSstrdup(). The mimetype argument is
-   optional, if not provided it defaults to "text/html". Sending an emptry
-   string would prevent setting a content type header (but that is not adviced).
+   optional, if not provided it defaults to "text/html". Sending an empty
+   string would prevent setting a content type header (but that is not advised).
 
    @param txnp HTTP transaction whose parent proxy to get.
    @param buf The body message (must be heap allocated).
@@ -1877,7 +1877,7 @@ tsapi TSAction TSCacheWrite(TSCont contp, TSCacheKey key);
     anything. The user does not get any vconnection from the cache,
     since no data needs to be transferred. When the cache calls
     contp back with TS_EVENT_CACHE_REMOVE, the remove has already
-    been commited.
+    been committed.
 
     @param contp continuation that the cache calls back reporting the
       success or failure of the remove.
@@ -2019,7 +2019,7 @@ tsapi void TSStatIntDecrement(int the_stat, TSMgmtInt amount);
 tsapi TSMgmtInt TSStatIntGet(int the_stat);
 tsapi void TSStatIntSet(int the_stat, TSMgmtInt value);
 /* Currently not supported. */
-/* tsapi TSeturnCode TSStatFloatGet(int the_stat, float* value); */
+/* tsapi TSReturnCode TSStatFloatGet(int the_stat, float* value); */
 /* tsapi TSReturnCode TSStatFloatSet(int the_stat, float value); */
 
 tsapi TSReturnCode TSStatFindName(const char *name, int *idp);
@@ -2033,7 +2033,7 @@ tsapi void TSDebug(const char *tag, const char *format_str, ...) TS_PRINTFLIKE(2
     Output a debug line even if the debug tag is turned off, as long as
     debugging is enabled. Could be used as follows:
     @code
-    TSDebugSpecifc(TSHttpTxnDebugGet(txn), "plugin_tag" , "Hello World from transaction %p", txn);
+    TSDebugSpecific(TSHttpTxnDebugGet(txn), "plugin_tag" , "Hello World from transaction %p", txn);
     @endcode
     will be printed if the plugin_tag is enabled or the transaction specific
     debugging is turned on for txn.
@@ -2397,7 +2397,7 @@ tsapi TSReturnCode TSHttpTxnMilestoneGet(TSHttpTxn txnp, TSMilestonesType milest
 tsapi int TSHttpTxnIsCacheable(TSHttpTxn txnp, TSMBuffer request, TSMBuffer response);
 
 /**
-   Return a string respresentation for a TSServerState value. This is useful for plugin debugging.
+   Return a string representation for a TSServerState value. This is useful for plugin debugging.
 
    @param state the value of this TSServerState
 
@@ -2406,7 +2406,7 @@ tsapi int TSHttpTxnIsCacheable(TSHttpTxn txnp, TSMBuffer request, TSMBuffer resp
 tsapi const char *TSHttpServerStateNameLookup(TSServerState state);
 
 /**
-   Return a string respresentation for a TSHttpHookID value. This is useful for plugin debugging.
+   Return a string representation for a TSHttpHookID value. This is useful for plugin debugging.
 
    @param hook the value of this TSHttpHookID
 
@@ -2415,7 +2415,7 @@ tsapi const char *TSHttpServerStateNameLookup(TSServerState state);
 tsapi const char *TSHttpHookNameLookup(TSHttpHookID hook);
 
 /**
-   Return a string respresentation for a TSEvent value. This is useful for plugin debugging.
+   Return a string representation for a TSEvent value. This is useful for plugin debugging.
 
    @param event the value of this TSHttpHookID
 
diff --git a/include/tscore/AcidPtr.h b/include/tscore/AcidPtr.h
index 6656705..bc4fc6f 100644
--- a/include/tscore/AcidPtr.h
+++ b/include/tscore/AcidPtr.h
@@ -35,7 +35,7 @@
 //////////////////////////////////////////////////////////
 // Lock Pool
 /// Intended to make datasets thread safe by assigning locks to stripes of data, kind of like a bloom filter.
-/** Allocates a fixed number of locks and retrives one with a hash.
+/** Allocates a fixed number of locks and retrieves one with a hash.
  */
 template <typename Mutex_t> struct LockPool {
   /**
@@ -152,7 +152,7 @@ protected:
 ///////////////////////////////////////////
 /// AcidCommitPtr
 
-/// a globally exclusive pointer, for commiting changes to AcidPtr.
+/// a globally exclusive pointer, for committing changes to AcidPtr.
 /** used for COPY_SWAP functionality.
  * 1. copy data (construct)
  * 2. overwrite data (scope)
diff --git a/include/tscore/Allocator.h b/include/tscore/Allocator.h
index 3de986a..c03f996 100644
--- a/include/tscore/Allocator.h
+++ b/include/tscore/Allocator.h
@@ -23,7 +23,7 @@
   Provides three classes
     - Allocator for allocating memory blocks of fixed size
     - ClassAllocator for allocating objects
-    - SpaceClassAllocator for allocating sparce objects (most members uninitialized)
+    - SpaceClassAllocator for allocating sparse objects (most members uninitialized)
 
   These class provides a efficient way for handling dynamic allocation.
   The fast allocator maintains its own freepool of objects from
diff --git a/include/tscore/ArgParser.h b/include/tscore/ArgParser.h
index 95a5a2d..45b0e41 100644
--- a/include/tscore/ArgParser.h
+++ b/include/tscore/ArgParser.h
@@ -176,7 +176,7 @@ public:
     // The help & version messages
     void help_message(std::string_view err = "") const;
     void version_message() const;
-    // Helpr method for parse()
+    // Helper method for parse()
     void append_option_data(Arguments &ret, AP_StrVec &args, int index);
     // The command name and help message
     std::string _name;
@@ -227,7 +227,7 @@ public:
                        std::string const &key = "");
   Command &add_command(std::string const &cmd_name, std::string const &cmd_description, std::string const &cmd_envvar,
                        unsigned cmd_arg_num, Function const &f = nullptr, std::string const &key = "");
-  // give a defaut command to this parser
+  // give a default command to this parser
   void set_default_command(std::string const &cmd);
   /** Main parsing function
       @return The Arguments object available for program using
diff --git a/include/tscore/AtomicBit.h b/include/tscore/AtomicBit.h
index 25d399f..72581d3 100644
--- a/include/tscore/AtomicBit.h
+++ b/include/tscore/AtomicBit.h
@@ -31,7 +31,7 @@
 
 //////////////////////////////////////////////////////
 /// AtomicBit for inplace atomic bit operations
-/* useful when you refernce a bit packed into a byte (unit_8) as a bool&,
+/* useful when you reference a bit packed into a byte (unit_8) as a bool&,
  * you want a bit to 'walk and talk' like an std::atomic<bool> or std::atomic_flag.
  * In practice this is constructed at time of the operation(s),
  * storing it would defeat the purpose of packing the bits.
diff --git a/include/tscore/BufferWriter.h b/include/tscore/BufferWriter.h
index 57b6c57..42610fa 100644
--- a/include/tscore/BufferWriter.h
+++ b/include/tscore/BufferWriter.h
@@ -105,7 +105,7 @@ public:
       invalidate the current auxiliary buffer (contents and address).
 
       Care must be taken to not write to data beyond this plus @c remaining bytes. Usually the
-      safest mechanism is to create a @c FixedBufferWriter on the auxillary buffer and write to that.
+      safest mechanism is to create a @c FixedBufferWriter on the auxiliary buffer and write to that.
 
       @code
       ts::FixedBufferWriter subw(w.auxBuffer(), w.remaining());
@@ -124,7 +124,7 @@ public:
   /** Advance the buffer position @a n bytes.
 
       This treats the next @a n bytes as being written without changing the content. This is useful
-      only in conjuction with @a auxBuffer to indicate that @a n bytes of the auxillary buffer has
+      only in conjunction with @a auxBuffer to indicate that @a n bytes of the auxiliary buffer has
       been written by some other mechanism.
 
       @internal Concrete subclasses @b must override this to advance in a way consistent with the
@@ -155,7 +155,7 @@ public:
   }
 
   /// Get the remaining buffer space.
-  /// @return Number of additional characters that can be written without causing an error condidtion.
+  /// @return Number of additional characters that can be written without causing an error condition.
   size_t
   remaining() const
   {
@@ -178,12 +178,12 @@ public:
   /** BufferWriter print.
 
       This prints its arguments to the @c BufferWriter @a w according to the format @a fmt. The format
-      string is based on Python style formating, each argument substitution marked by braces, {}. Each
-      specification has three parts, a @a name, a @a specifier, and an @a extention. These are
+      string is based on Python style formatting, each argument substitution marked by braces, {}. Each
+      specification has three parts, a @a name, a @a specifier, and an @a extension. These are
       separated by colons. The name should be either omitted or a number, the index of the argument to
       use. If omitted the place in the format string is used as the argument index. E.g. "{} {} {}",
       "{} {1} {}", and "{0} {1} {2}" are equivalent. Using an explicit index does not reset the
-      position of subsequent substiations, therefore "{} {0} {}" is equivalent to "{0} {0} {2}".
+      position of subsequent substitutions, therefore "{} {0} {}" is equivalent to "{0} {0} {2}".
   */
   template <typename... Rest> BufferWriter &print(TextView fmt, Rest &&... rest);
   /** Print overload to take arguments as a tuple instead of explicitly.
@@ -378,9 +378,9 @@ public:
 
   /** Get a @c FixedBufferWriter for the unused output buffer.
 
-      If @a reserve is non-zero then the buffer size for the auxillary writer will be @a reserve bytes
+      If @a reserve is non-zero then the buffer size for the auxiliary writer will be @a reserve bytes
       smaller than the remaining buffer. This "reserves" space for additional output after writing
-      to the auxillary buffer, in a manner similar to @c clip / @c extend.
+      to the auxiliary buffer, in a manner similar to @c clip / @c extend.
    */
   FixedBufferWriter
   auxWriter(size_t reserve = 0)
@@ -526,8 +526,8 @@ namespace bw_fmt
   }
 
   /// This exists only to expand the index sequence into an array of formatters for the tuple type
-  /// @a TUPLE.  Due to langauge limitations it cannot be done directly. The formatters can be
-  /// accessed via standard array access in constrast to templated tuple access. The actual array is
+  /// @a TUPLE.  Due to language limitations it cannot be done directly. The formatters can be
+  /// accessed via standard array access in contrast to templated tuple access. The actual array is
   /// static and therefore at run time the only operation is loading the address of the array.
   template <typename TUPLE, size_t... N>
   ArgFormatterSignature<TUPLE> *
@@ -625,7 +625,7 @@ BufferWriter::printv(TextView fmt, std::tuple<Args...> const &args)
   int arg_idx            = 0; // the next argument index to be processed.
 
   while (fmt.size()) {
-    // Next string piece of interest is an (optional) literal and then an (optinal) format specifier.
+    // Next string piece of interest is an (optional) literal and then an (optional) format specifier.
     // There will always be a specifier except for the possible trailing literal.
     std::string_view lit_v;
     std::string_view spec_v;
diff --git a/include/tscore/BufferWriterForward.h b/include/tscore/BufferWriterForward.h
index 9bc874c..50faa9e 100644
--- a/include/tscore/BufferWriterForward.h
+++ b/include/tscore/BufferWriterForward.h
@@ -60,7 +60,7 @@ struct BWFSpec {
   // @a _min is unsigned because there's no point in an invalid default, 0 works fine.
   unsigned int _min = 0;                                        ///< Minimum width.
   int _prec         = -1;                                       ///< Precision
-  unsigned int _max = std::numeric_limits<unsigned int>::max(); ///< Maxium width
+  unsigned int _max = std::numeric_limits<unsigned int>::max(); ///< Maximum width
   int _idx          = -1;                                       ///< Positional "name" of the specification.
   std::string_view _name;                                       ///< Name of the specification.
   std::string_view _ext;                                        ///< Extension if provided.
diff --git a/include/tscore/CryptoHash.h b/include/tscore/CryptoHash.h
index c9e1835..6fe34e1 100644
--- a/include/tscore/CryptoHash.h
+++ b/include/tscore/CryptoHash.h
@@ -126,7 +126,7 @@ public:
 
   /// Convenience - compute final @a hash for @a data.
   /// @note This is just as fast as the previous style, as a new context must be initialized
-  /// everytime this is done.
+  /// every time this is done.
   bool hash_immediate(CryptoHash &hash, void const *data, int length);
 };
 
diff --git a/include/tscore/Extendible.h b/include/tscore/Extendible.h
index e4f4682..add2f91 100644
--- a/include/tscore/Extendible.h
+++ b/include/tscore/Extendible.h
@@ -68,7 +68,7 @@ areStaticsFrozen()
  * @brief Allows code (and Plugins) to declare member variables during system init.
  *
  * The size of this structure is actually zero, so it will not change the size of your derived class.
- * But new and delete are overriden to use allocate enough bytes of the derived type + added fields.
+ * But new and delete are overridden to use allocate enough bytes of the derived type + added fields.
  * All bool's are packed to save space using the *Bit methods.
  * This API is focused on thread safe data types that allow minimally blocked reading.
  * This is templated so static variables are instanced per Derived type. B/c we need to have different
@@ -196,7 +196,7 @@ template <typename Derived_t> struct Extendible {
   }; // end Schema struct
 
 private:
-  // Extendible convience methods
+  // Extendible convenience methods
   char *this_as_char_ptr();
   char const *this_as_char_ptr() const;
 
@@ -392,7 +392,7 @@ void
 Extendible<Derived_t>::Schema::call_construct(char *ext_as_char_ptr)
 {
   ++instance_count; // don't allow schema modification
-  // init all extendible memory to 0, incase constructors don't
+  // init all extendible memory to 0, in case constructors don't
   memset(ext_as_char_ptr + sizeof(Derived_t), 0, alloc_size - sizeof(Derived_t));
 
   for (auto const &elm : fields) {
diff --git a/include/tscore/HostLookup.h b/include/tscore/HostLookup.h
index 58a0ec3..1d5bdb7 100644
--- a/include/tscore/HostLookup.h
+++ b/include/tscore/HostLookup.h
@@ -36,7 +36,7 @@
 #include <functional>
 #include <unordered_map>
 
-// HostLookup  constantss
+// HostLookup constants
 constexpr int HOST_TABLE_DEPTH = 3; // Controls the max number of levels in the logical tree
 constexpr int HOST_ARRAY_MAX   = 8; // Sets the fixed array size
 
diff --git a/include/tscore/I_Layout.h b/include/tscore/I_Layout.h
index 18aa141..eb4d260 100644
--- a/include/tscore/I_Layout.h
+++ b/include/tscore/I_Layout.h
@@ -65,7 +65,7 @@ struct Layout {
 
   /**
    Return file path relative to dir
-   Store the path to buf. The buf should be large eough to store
+   Store the path to buf. The buf should be large enough to store
    Example usage: Layout::relative_to(default_layout()->sysconfdir, "foo.bar");
   */
   static void relative_to(char *buf, size_t bufsz, std::string_view dir, std::string_view file);
diff --git a/include/tscore/IntrusiveHashMap.h b/include/tscore/IntrusiveHashMap.h
index 3e2b5c9..704b964 100644
--- a/include/tscore/IntrusiveHashMap.h
+++ b/include/tscore/IntrusiveHashMap.h
@@ -298,7 +298,7 @@ protected:
 
   Bucket *bucket_for(key_type key);
 
-  ExpansionPolicy _expansion_policy{DEFAULT_EXPANSION_POLICY}; ///< When to exand the table.
+  ExpansionPolicy _expansion_policy{DEFAULT_EXPANSION_POLICY}; ///< When to expand the table.
   size_t _expansion_limit{DEFAULT_EXPANSION_LIMIT};            ///< Limit value for expansion.
 
   // noncopyable
diff --git a/include/tscore/IpMap.h b/include/tscore/IpMap.h
index 568374e..50a9fbe 100644
--- a/include/tscore/IpMap.h
+++ b/include/tscore/IpMap.h
@@ -75,7 +75,7 @@ namespace detail
     data. Marking takes a painter's algorithm approach -- any marking
     overwrites any previous marking on an address. Details of marking
     calls are discarded and only the final results are kept. That is,
-    a client cannot unmark expliticly any previous marking. Only a
+    a client cannot unmark explicitly any previous marking. Only a
     specific range of addresses can be unmarked.
 
     Both IPv4 and IPv6 are supported in the same map. Mixed ranges are
@@ -310,7 +310,7 @@ public:
 
   /** Test for membership.
 
-      @note Covenience overload for IPv4.
+      @note Convenience overload for IPv4.
 
       @return @c true if the address is in the map, @c false if not.
       If the address is in the map and @a ptr is not @c nullptr, @c *ptr
diff --git a/include/tscore/MemArena.h b/include/tscore/MemArena.h
index 3a3519a..8d0d8cc 100644
--- a/include/tscore/MemArena.h
+++ b/include/tscore/MemArena.h
@@ -168,7 +168,7 @@ public:
 
   /** Release all memory.
 
-      Empties the entire arena and deallocates all underlying memory. The hint for the next reservered block size will
+      Empties the entire arena and deallocates all underlying memory. The hint for the next reserved block size will
       be @a n if @a n is not zero, otherwise it will be the sum of all allocations when this method was called.
 
       @return @c *this
diff --git a/include/tscore/ParseRules.h b/include/tscore/ParseRules.h
index 847522e..e69e737 100644
--- a/include/tscore/ParseRules.h
+++ b/include/tscore/ParseRules.h
@@ -136,7 +136,7 @@ public:
   //////////////////
 
   static CTypeResult is_escape(const char *seq); // %<hex><hex>
-  static CTypeResult is_uchar(const char *seq);  // starts unresrvd or is escape
+  static CTypeResult is_uchar(const char *seq);  // starts unreserved or is escape
   static CTypeResult is_pchar(const char *seq);  // uchar,:,@,&,=,+ (see code)
 
   ///////////////////
@@ -766,7 +766,7 @@ ParseRules::strlen_eow(const char *s)
 //
 //  This function is the same as strstr(), except that it accepts strings
 //  that are terminated with '\r', '\n' or null.
-//  It returns a pointer to the first occurance of s2 within s1 (or null).
+//  It returns a pointer to the first occurrence of s2 within s1 (or null).
 //////////////////////////////////////////////////////////////////////////////
 inline const char *
 ParseRules::strstr_eow(const char *s1, const char *s2)
diff --git a/include/tscore/Ptr.h b/include/tscore/Ptr.h
index 559f346..3a79e01 100644
--- a/include/tscore/Ptr.h
+++ b/include/tscore/Ptr.h
@@ -143,7 +143,7 @@ public:
   }
 
   // Return the raw pointer as a RefCount object. Typically
-  // this is for keeping a collection of heterogenous objects.
+  // this is for keeping a collection of ogenous objects.
   RefCountObj *
   object() const
   {
diff --git a/include/tscore/Scalar.h b/include/tscore/Scalar.h
index 06c3398..5eb0dff 100644
--- a/include/tscore/Scalar.h
+++ b/include/tscore/Scalar.h
@@ -224,7 +224,7 @@ public:
   static_assert(N > 0, "The scaling factor (1st template argument) must be a positive integer");
   static_assert(std::is_integral<C>::value, "The counter type (2nd template argument) must be an integral type");
 
-  constexpr Scalar(); ///< Default contructor.
+  constexpr Scalar(); ///< Default constructor.
   ///< Construct to have @a n scaled units.
   explicit constexpr Scalar(Counter n);
   /// Copy constructor.
@@ -872,7 +872,7 @@ template <intmax_t N, typename C, typename T, typename I>
 Scalar<N, C, T>
 operator/(Scalar<N, C, T> lhs, I n)
 {
-  static_assert(std::is_integral<I>::value, "Scalar divsion only support integral types.");
+  static_assert(std::is_integral<I>::value, "Scalar division only support integral types.");
   return Scalar<N, C, T>(lhs) /= n;
 }
 
diff --git a/include/tscore/SimpleTokenizer.h b/include/tscore/SimpleTokenizer.h
index 15471ef..82a257f 100644
--- a/include/tscore/SimpleTokenizer.h
+++ b/include/tscore/SimpleTokenizer.h
@@ -127,7 +127,7 @@ public:
   {
   }
 
-  // NOTE: The input strring 's' is overwritten for mode OVERWRITE_INPUT_STRING.
+  // NOTE: The input string 's' is overwritten for mode OVERWRITE_INPUT_STRING.
   SimpleTokenizer(const char *s, char delimiter = ' ', unsigned mode = 0, char escape = '\\')
     : _delimiter(delimiter), _mode(mode), _escape(escape)
   {
diff --git a/include/tscore/TextBuffer.h b/include/tscore/TextBuffer.h
index 8ef01de..65dd1ec 100644
--- a/include/tscore/TextBuffer.h
+++ b/include/tscore/TextBuffer.h
@@ -25,7 +25,7 @@
 
 /****************************************************************************
  *
- *  TextBuffer.h - A self-expanding buffer, primarly meant for strings
+ *  TextBuffer.h - A self-expanding buffer, primarily meant for strings
  *
  *
  *
diff --git a/include/tscore/Tokenizer.h b/include/tscore/Tokenizer.h
index 562279b..a86c96a 100644
--- a/include/tscore/Tokenizer.h
+++ b/include/tscore/Tokenizer.h
@@ -43,26 +43,26 @@
  *
  *  There are three memory options.
  *     SHARE_TOKS - this modifies the original string passed in
- *          through Intialize() and shares its space.   NULLs
+ *          through Initialize() and shares its space.   NULLs
  *          are inserted into string after each token.  Choosing
- *          this option means the user is reponsible for not
+ *          this option means the user is responsible for not
  *          deallocating the string storage before deallocating
  *          the tokenizer object
- *     COPY_TOKS - this option copies the orginial string and
+ *     COPY_TOKS - this option copies the original string and
  *          leaves the original unchanged.  The deallocation of the
  *          original string and the deallocation of the Tokenizer
  *          object are now independent.
  *     Note: If neither SHARE_TOKS or COPY_TOKS is selected, COPY_TOKS
  *          is the default
  *     ALLOW_EMPTY_TOKENS: If multiple delimiters appear next to each
- *          other, each delimiter creates a token someof which
+ *          other, each delimiter creates a token some of which
  *          will be zero length.  The default is to skip repeated
  *          delimiters
  *
  *  Tokenizer(const char* StrOfDelimit) - a string that contains
  *     the delimiters for tokenizing.  This string is copied.
  *
- *  Intialize(char* str, TokenizerOpts opt) - Submits a string
+ *  Initialize(char* str, TokenizerOpts opt) - Submits a string
  *     to be tokenized according to the memory options listed above
  *
  *  ReUse() - Allows the object to be reused for a new string
@@ -76,7 +76,7 @@
  *     is intended to be used on a small number of tokens
  *
  *  iterFirst(tok_iter_state* state) - Returns the first
- *     token and intializes state argument for subsequent
+ *     token and initializes state argument for subsequent
  *     calls to iterNext.  If no tokens exist, NULL is
  *     returned
  *
diff --git a/include/tscore/ink_base64.h b/include/tscore/ink_base64.h
index b536fd6..a3c4d51 100644
--- a/include/tscore/ink_base64.h
+++ b/include/tscore/ink_base64.h
@@ -25,7 +25,7 @@
 
 /*
  * Base64 encoding and decoding as according to RFC1521.  Similar to uudecode.
- * See RFC1521 for specificiation.
+ * See RFC1521 for specification.
  *
  * RFC 1521 requires inserting line breaks for long lines.  The basic web
  * authentication scheme does not require them.  This implementation is
diff --git a/include/tscore/ink_cap.h b/include/tscore/ink_cap.h
index 4a2c7d5..6ffaccb 100644
--- a/include/tscore/ink_cap.h
+++ b/include/tscore/ink_cap.h
@@ -52,7 +52,7 @@ extern FILE *elevating_fopen(const char *path, const char *mode);
 
 // chmod a file, elevating if necessary
 extern int elevating_chmod(const char *path, int perm);
-/// @c stat a file, evelating only if needed.
+/// @c stat a file, elevating only if needed.
 extern int elevating_stat(const char *path, struct stat *buff);
 
 /** Control generate of core file on crash.
diff --git a/include/tscore/ink_code.h b/include/tscore/ink_code.h
index 2b08574..c10dd1e 100644
--- a/include/tscore/ink_code.h
+++ b/include/tscore/ink_code.h
@@ -32,7 +32,7 @@
 typedef MD5_CTX INK_DIGEST_CTX;
 
 /*
-  Wrappers around the MD5 functions, all of this should be depericated and just use the functions directly
+  Wrappers around the MD5 functions, all of this should be deprecated and just use the functions directly
 */
 
 inkcoreapi int ink_code_md5(unsigned const char *input, int input_length, unsigned char *sixteen_byte_hash_pointer);
diff --git a/include/tscore/ink_endian.h b/include/tscore/ink_endian.h
index 30b3132..cee79d4 100644
--- a/include/tscore/ink_endian.h
+++ b/include/tscore/ink_endian.h
@@ -1,6 +1,6 @@
 /** @file
  *
- *  Endian convertion routines
+ *  Endian conversion routines
  *
  *  @section license License
  *
diff --git a/include/tscore/ink_file.h b/include/tscore/ink_file.h
index fb0487c..6cb656f 100644
--- a/include/tscore/ink_file.h
+++ b/include/tscore/ink_file.h
@@ -45,7 +45,7 @@
 #include <sys/statvfs.h>
 #endif
 
-// Darwin keeps statafs(2) in <sys/mount.h> ...
+// Darwin keeps statfs(2) in <sys/mount.h> ...
 #if HAVE_SYS_MOUNT_H
 #include <sys/mount.h>
 #endif
diff --git a/include/tscore/ink_hrtime.h b/include/tscore/ink_hrtime.h
index f321476..9358b63 100644
--- a/include/tscore/ink_hrtime.h
+++ b/include/tscore/ink_hrtime.h
@@ -44,7 +44,7 @@ char *int64_to_str(char *buf, unsigned int buf_size, int64_t val, unsigned int *
 
 //////////////////////////////////////////////////////////////////////////////
 //
-//      Factors to multiply units by to obtain coresponding ink_hrtime values.
+//      Factors to multiply units by to obtain corresponding ink_hrtime values.
 //
 //////////////////////////////////////////////////////////////////////////////
 
@@ -81,7 +81,7 @@ char *int64_to_str(char *buf, unsigned int buf_size, int64_t val, unsigned int *
 #define HRTIME_USECONDS(_x) ((_x)*HRTIME_USECOND)
 #define HRTIME_NSECONDS(_x) ((_x)*HRTIME_NSECOND)
 
-// gratuituous wrappers
+// gratuitous wrappers
 
 static inline ink_hrtime
 ink_hrtime_from_years(unsigned int years)
diff --git a/include/tscore/ink_inet.h b/include/tscore/ink_inet.h
index 3940337..ff6c104 100644
--- a/include/tscore/ink_inet.h
+++ b/include/tscore/ink_inet.h
@@ -117,7 +117,7 @@ union IpEndpoint {
   in_port_t &port();
   /// Port in network order.
   in_port_t port() const;
-  /// Port in host horder.
+  /// Port in host order.
   in_port_t host_order_port() const;
 
   operator sockaddr *() { return &sa; }
diff --git a/include/tscore/ink_lockfile.h b/include/tscore/ink_lockfile.h
index 8f5aa2e..dab7061 100644
--- a/include/tscore/ink_lockfile.h
+++ b/include/tscore/ink_lockfile.h
@@ -79,7 +79,7 @@ public:
   // If the lock file open succeeds, it closes the lock file releasing
   // the lock.
   //
-  // The intial signal can be used to generate a core from the process while
+  // The initial signal can be used to generate a core from the process while
   // still ensuring it dies.
   void Kill(int sig, int initial_sig = 0, const char *pname = nullptr);
   void KillGroup(int sig, int initial_sig = 0, const char *pname = nullptr);
diff --git a/include/tscore/ink_resolver.h b/include/tscore/ink_resolver.h
index fee4084..b9af473 100644
--- a/include/tscore/ink_resolver.h
+++ b/include/tscore/ink_resolver.h
@@ -109,7 +109,7 @@
 #define INK_RES_AAONLY 0x00000004         /*%< authoritative answers only (!IMPL)*/
 #define INK_RES_USEVC 0x00000008          /*%< use virtual circuit */
 #define INK_RES_PRIMARY 0x00000010        /*%< query primary server only (!IMPL) */
-#define INK_RES_IGNTC 0x00000020          /*%< ignore trucation errors */
+#define INK_RES_IGNTC 0x00000020          /*%< ignore truncation errors */
 #define INK_RES_RECURSE 0x00000040        /*%< recursion desired */
 #define INK_RES_DEFNAMES 0x00000080       /*%< use default domain name */
 #define INK_RES_STAYOPEN 0x00000100       /*%< Keep TCP socket open */
@@ -181,7 +181,7 @@ enum HostResStyle {
 /// Strings for host resolution styles
 extern const char *const HOST_RES_STYLE_STRING[];
 
-/// Caclulate the effective resolution preferences.
+/// Calculate the effective resolution preferences.
 extern HostResStyle ats_host_res_from(int family,            ///< Connection family
                                       HostResPreferenceOrder ///< Preference ordering.
 );
diff --git a/include/tscore/signals.h b/include/tscore/signals.h
index 5e23ab4..54fc9e5 100644
--- a/include/tscore/signals.h
+++ b/include/tscore/signals.h
@@ -50,6 +50,6 @@ bool signal_is_masked(int signo);
 // Test whether the signal is being handled by the given handler.
 bool signal_check_handler(int signo, signal_handler_t handler);
 
-// Start a thread to test whether signals have the expected handler. Apparantly useful for
+// Start a thread to test whether signals have the expected handler. Apparently useful for
 // finding pthread bugs in some version of DEC Unix.
 void signal_start_check_thread(signal_handler_t handler);
diff --git a/include/tscpp/api/Continuation.h b/include/tscpp/api/Continuation.h
index ef25dab..1557ecc 100644
--- a/include/tscpp/api/Continuation.h
+++ b/include/tscpp/api/Continuation.h
@@ -41,7 +41,7 @@ public:
     TSContDataSet(_cont, static_cast<void *>(this));
   }
 
-  // Create "empty" continuation, can only be populated by move assignement.
+  // Create "empty" continuation, can only be populated by move assignment.
   //
   Continuation() {}
 
@@ -131,7 +131,7 @@ public:
   }
 
 protected:
-  // Distinct continuation behavior is acheived by overriding this function in a derived continutation type.
+  // Distinct continuation behavior is achieved by overriding this function in a derived continuation type.
   //
   virtual int _run(TSEvent event, void *edata) = 0;
 
diff --git a/include/tscpp/api/GlobalPlugin.h b/include/tscpp/api/GlobalPlugin.h
index 1df60bd..1d76ed5 100644
--- a/include/tscpp/api/GlobalPlugin.h
+++ b/include/tscpp/api/GlobalPlugin.h
@@ -33,7 +33,7 @@ struct GlobalPluginState;
  * @brief The interface used when creating a GlobalPlugin.
  *
  * A GlobalPlugin is a Plugin that will fire for a given hook on all Transactions.
- * In otherwords, a GlobalPlugin is not tied to a specific plugin, a Transaction
+ * In other words, a GlobalPlugin is not tied to a specific plugin, a Transaction
  * specific plugin would be a TransactionPlugin.
  *
  * Depending on the
@@ -60,9 +60,9 @@ public:
   /**
    * registerHook is the mechanism used to attach a global hook.
    *
-   * \note Whenever you register a hook you must have the appropriate callback definied in your GlobalPlugin
+   * \note Whenever you register a hook you must have the appropriate callback defined in your GlobalPlugin
    *  see HookType and Plugin for the correspond HookTypes and callback methods. If you fail to implement the
-   *  callback, a default implmentation will be used that will only resume the Transaction.
+   *  callback, a default implementation will be used that will only resume the Transaction.
    *
    * @param HookType the type of hook you wish to register
    * @see HookType
diff --git a/include/tscpp/api/GzipDeflateTransformation.h b/include/tscpp/api/GzipDeflateTransformation.h
index 039965e..10cfb62 100644
--- a/include/tscpp/api/GzipDeflateTransformation.h
+++ b/include/tscpp/api/GzipDeflateTransformation.h
@@ -42,7 +42,7 @@ namespace transformations
    *
    * The GzipDeflateTransformation is a helper transformation that can be used
    * to easily compress content. For a full example of GzipDeflateTransformation
-   * and GzipInflateTransformation see examples/gzip_transformation/.
+   * and GzipInflateTransformation see example/cppapi/gzip_transformation/.
    *
    * @note GzipDeflateTransformation DOES NOT set Content-Encoding headers, it is the
    * users responsibility to set any applicable headers.
@@ -54,7 +54,7 @@ namespace transformations
   public:
     /**
      * A full example of how to use GzipDeflateTransformation and GzipInflateTransformation is available
-     * in examples/gzip_tranformation/
+     * in example/cppapi/gzip_transformation/
      *
      * @param transaction As with any TransformationPlugin you must pass in the transaction
      * @param type because the GzipDeflateTransformation can be used with both requests and responses
@@ -74,7 +74,7 @@ namespace transformations
 
     /**
      * Any TransformationPlugin must implement handleInputComplete(), this method will
-     * finalize the gzip compression and flush any remaining data and the epilouge.
+     * finalize the gzip compression and flush any remaining data and the epilogue.
      */
     void handleInputComplete() override;
 
diff --git a/include/tscpp/api/GzipInflateTransformation.h b/include/tscpp/api/GzipInflateTransformation.h
index c664c18..358fdc7 100644
--- a/include/tscpp/api/GzipInflateTransformation.h
+++ b/include/tscpp/api/GzipInflateTransformation.h
@@ -41,12 +41,12 @@ namespace transformations
    *
    * The GzipInflateTransformation is a helper transformation that can be used
    * to easily decompress gzipped content. For a full example of GzipInflateTransformation
-   * and GzipDeflateTransformation see examples/gzip_transformation/.
+   * and GzipDeflateTransformation see example/cppapi/gzip_transformation/.
    *
    * @note GzipDeflateTransformation DOES NOT set or check Content-Encoding headers, it is the
-   * users responsibility to set any applicable headers and check that the content is acctually
+   * users responsibility to set any applicable headers and check that the content is actually
    * gzipped by checking the Content-Encoding header before creating a GzipInflateTransformation,
-   * see examples/gzip_transformation/ for a full example.
+   * see example/cppapi/gzip_transformation/ for a full example.
    *
    * @see GzipDeflateTransformation
    */
@@ -55,7 +55,7 @@ namespace transformations
   public:
     /**
      * A full example of how to use GzipInflateTransformation and GzipDeflateTransformation is available
-     * in examples/gzip_tranformation/
+     * in example/cppapi/gzip_transformation/.
      *
      * @param transaction As with any TransformationPlugin you must pass in the transaction
      * @param type because the GzipInflateTransformation can be used with both requests and responses
diff --git a/include/tscpp/api/Headers.h b/include/tscpp/api/Headers.h
index 25e1ce1..c956ff4 100644
--- a/include/tscpp/api/Headers.h
+++ b/include/tscpp/api/Headers.h
@@ -36,7 +36,7 @@ class Response;
 
 /**
  * @brief A HeaderFieldName is a lightweight wrapper around a string that allows for case insensitive comparisons.
- * Because header field names must be case insensitive this allows easy case insentive comparisons of names.
+ * Because header field names must be case insensitive this allows easy case insensitive comparisons of names.
  *
  */
 class HeaderFieldName
@@ -75,7 +75,7 @@ public:
   std::string str();
 
   /**
-   * @return a const char * which points to the name of this HeaderFIeldName
+   * @return a const char * which points to the name of this HeaderFieldName
    */
   const char *c_str();
 
@@ -119,7 +119,7 @@ public:
    * Constructor for header_field_value_iterator, this shouldn't need to be used directly.
    * @param bufp the TSMBuffer associated with the headers
    * @param mloc the TSMLoc associated with the headers.
-   * @param field_loc the TSMLoc assocated with the field.
+   * @param field_loc the TSMLoc associated with the field.
    * @param index the index of the value in the HeaderField
    * @warning This shouldn't need to be used directly!
    */
@@ -358,14 +358,14 @@ public:
   /**
    * Set the VALUES of the header field to the given value string
    * @param string - the values to set on the current header field
-   * @return true if the value is sucessfully changed.
+   * @return true if the value is successfully changed.
    */
   bool operator=(const std::string &field_value);
 
   /**
    * Set the VALUES of the header field to the given value string
    * @param the values to set on the current header field
-   * @return true if the value is sucessfully changed.
+   * @return true if the value is successfully changed.
    */
   bool operator=(const char *field_value);
 
@@ -464,7 +464,7 @@ public:
 
   /**
    * Clears all headers.
-   * @return true if the headers were succesfully cleared.
+   * @return true if the headers were successfully cleared.
    */
   bool clear();
 
@@ -574,7 +574,7 @@ public:
    * @param key the name of the header field whose value to set.
    * @return an iterator to the new header field or the end() iterator if append fails.
    * @warning This will create a header field with the given name, thus it should not be
-   * used to check for the existance of a header, use count() or find() instead.
+   * used to check for the existence of a header, use count() or find() instead.
    */
   HeaderField operator[](const std::string &key);
 
diff --git a/include/tscpp/api/Logger.h b/include/tscpp/api/Logger.h
index 8bd2e4e..08eb50f 100644
--- a/include/tscpp/api/Logger.h
+++ b/include/tscpp/api/Logger.h
@@ -34,7 +34,7 @@
 #if !defined(ATSCPPAPI_PRINTFLIKE)
 #if defined(__GNUC__) || defined(__clang__)
 /**
- * This macro will tell GCC that the function takes printf like arugments
+ * This macro will tell GCC that the function takes printf like arguments
  * this is helpful because it can produce better warning and error messages
  * when a user doesn't use the methods correctly.
  *
@@ -81,7 +81,7 @@
 /**
  * We forward declare this because if we didn't we end up writing our
  * own version to do the vsnprintf just to call TSDebug and have it do
- * an unncessary vsnprintf.
+ * an unnecessary vsnprintf.
  *
  * @private
  */
@@ -90,7 +90,7 @@ extern "C" void TSDebug(const char *tag, const char *fmt, ...) ATSCPPAPI_PRINTFL
 /**
  * We forward declare this because if we didn't we end up writing our
  * own version to do the vsnprintf just to call TSError and have it do
- * an unncessary vsnprintf.
+ * an unnecessary vsnprintf.
  *
  * @private
  */
@@ -225,7 +225,7 @@ public:
 
   /**
    * This method allows you to flush any log lines that might have been buffered.
-   * @warning This method can cause serious performance degredation so you should only
+   * @warning This method can cause serious performance degradation so you should only
    * use it when absolutely necessary.
    */
   void flush();
diff --git a/include/tscpp/api/Plugin.h b/include/tscpp/api/Plugin.h
index 59e755a..2f57352 100644
--- a/include/tscpp/api/Plugin.h
+++ b/include/tscpp/api/Plugin.h
@@ -18,7 +18,7 @@
 /**
  * @file Plugin.h
  *
- * @brief Contains the base interface used in creating Global and Transaciton plugins.
+ * @brief Contains the base interface used in creating Global and Transaction plugins.
  * \note This interface can never be implemented directly, it should be implemented
  *   through extending GlobalPlugin, TransactionPlugin, or TransformationPlugin.
  */
@@ -49,15 +49,15 @@ public:
    * and TransactionPlugin::registerHook().
    */
   enum HookType {
-    HOOK_READ_REQUEST_HEADERS_PRE_REMAP = 0, /**< This hook will be fired before remap has occured. */
-    HOOK_READ_REQUEST_HEADERS_POST_REMAP,    /**< This hook will be fired directly after remap has occured. */
+    HOOK_READ_REQUEST_HEADERS_PRE_REMAP = 0, /**< This hook will be fired before remap has occurred. */
+    HOOK_READ_REQUEST_HEADERS_POST_REMAP,    /**< This hook will be fired directly after remap has occurred. */
     HOOK_SEND_REQUEST_HEADERS,               /**< This hook will be fired right before request headers are sent to the origin */
     HOOK_READ_RESPONSE_HEADERS, /**< This hook will be fired right after response headers have been read from the origin */
     HOOK_SEND_RESPONSE_HEADERS, /**< This hook will be fired right before the response headers are sent to the client */
     HOOK_OS_DNS,                /**< This hook will be fired right after the OS DNS lookup */
     HOOK_READ_REQUEST_HEADERS,  /**< This hook will be fired after the request is read. */
     HOOK_READ_CACHE_HEADERS,    /**< This hook will be fired after the CACHE hdrs. */
-    HOOK_CACHE_LOOKUP_COMPLETE, /**< This hook will be fired after caceh lookup complete. */
+    HOOK_CACHE_LOOKUP_COMPLETE, /**< This hook will be fired after cache lookup complete. */
     HOOK_SELECT_ALT             /**< This hook will be fired after select alt. */
   };
 
diff --git a/include/tscpp/api/RemapPlugin.h b/include/tscpp/api/RemapPlugin.h
index 8b0840c..44e550e 100644
--- a/include/tscpp/api/RemapPlugin.h
+++ b/include/tscpp/api/RemapPlugin.h
@@ -59,7 +59,7 @@ public:
    * @param redirect Output argument that should be set to true if the (new) url should be used
    *                 as a redirect.
    *
-   * @return Result of the remap - will dictate futher processing by the system.
+   * @return Result of the remap - will dictate further processing by the system.
    */
   virtual Result
   doRemap(const Url &map_from_url ATSCPPAPI_UNUSED, const Url &map_to_url ATSCPPAPI_UNUSED,
diff --git a/include/tscpp/api/Stat.h b/include/tscpp/api/Stat.h
index a5a8440..ba87c6d 100644
--- a/include/tscpp/api/Stat.h
+++ b/include/tscpp/api/Stat.h
@@ -65,7 +65,7 @@ public:
   /**
    * You must initialize your Stat with a call to this init() method.
    *
-   * @param name The string name of the stat, this will be visbible via traffic_ctl, or through http stats.
+   * @param name The string name of the stat, this will be visible via traffic_ctl, or through http stats.
    * @param type The SyncType of the Stat, this decides how TrafficServer will treat your inputs. The default
    *   value is SYNC_COUNT.
    * @param persistent This determines if your Stats will persist, the default value is false.
diff --git a/include/tscpp/api/Transaction.h b/include/tscpp/api/Transaction.h
index e70bb7a..874c315 100644
--- a/include/tscpp/api/Transaction.h
+++ b/include/tscpp/api/Transaction.h
@@ -132,7 +132,7 @@ public:
 
   /**
    * Sets the error body page but this method does not advance the state machine to the error state.
-   * To do that you must explicitally call error().
+   * To do that you must explicitly call error().
    *
    * @param content the error page content.
    */
@@ -141,7 +141,7 @@ public:
   /**
    * Sets the error body page with mimetype.
    * This method does not advance the state machine to the error state.
-   * To do that you must explicitally call error().
+   * To do that you must explicitly call error().
    *
    * @param content the error page content.
    * @param mimetype the error page's content-type.
@@ -340,7 +340,7 @@ public:
   size_t getServerResponseBodySize();
 
   /**
-   * Get the nubmber of bytes for the response headers as returned by the server
+   * Get the number of bytes for the response headers as returned by the server
    *
    * @return server response header size */
   size_t getServerResponseHeaderSize();
diff --git a/include/tscpp/api/TransactionPlugin.h b/include/tscpp/api/TransactionPlugin.h
index 8f59c22..b34fba0 100644
--- a/include/tscpp/api/TransactionPlugin.h
+++ b/include/tscpp/api/TransactionPlugin.h
@@ -17,7 +17,7 @@
  */
 /**
  * @file TransactionPlugin.h
- * @brief Contains the interface used in creating Transaciton plugins.
+ * @brief Contains the interface used in creating Transaction plugins.
  */
 
 #pragma once
@@ -62,7 +62,7 @@ struct TransactionPluginState;
  * You must always be sure to implement the appropriate callback for the type of hook you register.
  *
  * \code
- * // For a more detailed example see examples/transactionhook/
+ * // For a more detailed example see example/cppapi/transactionhook/
  * class TransactionHookPlugin : publicTransactionPlugin {
  * public:
  *   TransactionHookPlugin(Transaction &transaction) : TransactionPlugin(transaction) {
@@ -89,9 +89,9 @@ public:
   /**
    * registerHook is the mechanism used to attach a transaction hook.
    *
-   * \note Whenever you register a hook you must have the appropriate callback definied in your TransactionPlugin
+   * \note Whenever you register a hook you must have the appropriate callback defined in your TransactionPlugin
    *  see HookType and Plugin for the correspond HookTypes and callback methods. If you fail to implement the
-   *  callback, a default implmentation will be used that will only resume the Transaction.
+   *  callback, a default implementation will be used that will only resume the Transaction.
    *
    * @param HookType the type of hook you wish to register
    * @see HookType
diff --git a/include/tscpp/api/TransformationPlugin.h b/include/tscpp/api/TransformationPlugin.h
index c31ef45..e9b1a7f 100644
--- a/include/tscpp/api/TransformationPlugin.h
+++ b/include/tscpp/api/TransformationPlugin.h
@@ -46,7 +46,7 @@ class Continuation;
  * the appropriate callback for any hooks you register.
  *
  * A simple example of how to use the TransformationPlugin interface follows, this is an example
- * of a Response transformation, the avialable options are REQUEST_TRANSFORMATION and RESPONSE_TRANSFORMATION
+ * of a Response transformation, the available options are REQUEST_TRANSFORMATION and RESPONSE_TRANSFORMATION
  * which are defined in Type.
  *
  * This example is a Null Transformation, meaning it will just spit out the content it receives without
@@ -128,7 +128,7 @@ protected:
 
   /**
    * This is the method that you must call when you're done producing output for
-   * the downstream TranformationPlugin.
+   * the downstream TransformationPlugin.
    */
   size_t setOutputComplete();
 
diff --git a/include/tscpp/api/noncopyable.h b/include/tscpp/api/noncopyable.h
index 997b7ff..304449b 100644
--- a/include/tscpp/api/noncopyable.h
+++ b/include/tscpp/api/noncopyable.h
@@ -18,7 +18,7 @@
 
 /**
  * @file noncopyable.h
- * @brief A base class used to prevent dervied classes from being copyable, this effectively
+ * @brief A base class used to prevent derived classes from being copyable, this effectively
  * eliminates the copy constructor and assignment operator.
  */
 
diff --git a/include/tscpp/util/IntrusiveDList.h b/include/tscpp/util/IntrusiveDList.h
index eae1f0e..e94fda3 100644
--- a/include/tscpp/util/IntrusiveDList.h
+++ b/include/tscpp/util/IntrusiveDList.h
@@ -55,7 +55,7 @@ namespace ts
     It is the responsibility of the item class to initialize the link pointers. When an item is
     removed from the list the link pointers are set to @c nullptr.
 
-    An example declaration woudl be
+    An example declaration would be
 
     @code
       // Item in the list.
@@ -137,7 +137,7 @@ public:
     value_type *operator->() const;
 
     /// Convenience conversion to pointer type
-    /// Because of how this list is normally used, being able to pass an iterator as a pointer is quite convienent.
+    /// Because of how this list is normally used, being able to pass an iterator as a pointer is quite convenient.
     /// If the iterator isn't valid, it converts to @c nullptr.
     operator value_type *() const;
 
@@ -150,7 +150,7 @@ public:
   protected:
     // These are stored non-const to make implementing @c iterator easier. This class provides the required @c const
     // protection.
-    list_type *_list{nullptr};                   ///< Needed to descrement from @c end() position.
+    list_type *_list{nullptr};                   ///< Needed to decrement from @c end() position.
     typename list_type::value_type *_v{nullptr}; ///< Referenced element.
 
     /// Internal constructor for containers.
@@ -242,11 +242,11 @@ public:
   self_type &append(value_type *v);
 
   /// Remove the first element of the list.
-  /// @return A poiner to the removed item, or @c nullptr if the list was empty.
+  /// @return A pointer to the removed item, or @c nullptr if the list was empty.
   value_type *take_head();
 
   /// Remove the last element of the list.
-  /// @return A poiner to the removed item, or @c nullptr if the list was empty.
+  /// @return A pointer to the removed item, or @c nullptr if the list was empty.
   value_type *take_tail();
 
   /// Insert a new element @a elt after @a target.
@@ -354,7 +354,7 @@ protected:
  */
 template <typename T, T *(T::*NEXT) = &T::_next, T *(T::*PREV) = &T::_prev> struct IntrusiveLinkage {
   static T *&next_ptr(T *thing); ///< Retrieve reference to next pointer.
-  static T *&prev_ptr(T *thing); ///< Retrive reference to previous pointer.
+  static T *&prev_ptr(T *thing); ///< Retrieve reference to previous pointer.
 };
 
 template <typename T, T *(T::*NEXT), T *(T::*PREV)>
diff --git a/include/tscpp/util/MemSpan.h b/include/tscpp/util/MemSpan.h
index f0a2890..9779e02 100644
--- a/include/tscpp/util/MemSpan.h
+++ b/include/tscpp/util/MemSpan.h
@@ -224,7 +224,7 @@ public:
    */
 
   self_type remove_prefix(void const *p);
-  /** Shringt the span from the front.
+  /** Shrink the span from the front.
    *
    * @param n The number of bytes to remove.
    * @return @c *this
@@ -254,7 +254,7 @@ public:
    */
   self_type &remove_suffix(void const *p);
 
-  /** Shringt the span from the back.
+  /** Shrink the span from the back.
    *
    * @param n The number of bytes to remove.
    * @return @c *this
diff --git a/include/tscpp/util/TextView.h b/include/tscpp/util/TextView.h
index ce620df..e82044f 100644
--- a/include/tscpp/util/TextView.h
+++ b/include/tscpp/util/TextView.h
@@ -99,7 +99,7 @@ public:
 
   /** Construct explicitly with a pointer and size.
       If @a n is negative it is treated as 0.
-      @internal Overload for convience, otherwise get "narrow conversion" errors.
+      @internal Overload for convenience, otherwise get "narrow conversion" errors.
    */
   constexpr TextView(const char *ptr, ///< Pointer to buffer.
                      int n            ///< Size of buffer.
@@ -116,7 +116,7 @@ public:
 
       Construct directly from an array of characters. All elements of the array are
       included in the view unless the last element is nul, in which case it is elided.
-      If this is inapropriate then a constructor with an explicit size should be used.
+      If this is inappropriate then a constructor with an explicit size should be used.
 
       @code
         TextView a("A literal string");
@@ -291,10 +291,10 @@ public:
   /// Overload to provide better return type.
   self_type &remove_prefix(size_t n);
 
-  /// Remove the prefix delimited by the first occurence of @a c.
+  /// Remove the prefix delimited by the first occurrence of @a c.
   self_type &remove_prefix_at(char c);
 
-  /// Remove the prefix delimited by the first occurence of a character for which @a pred is @c true.
+  /// Remove the prefix delimited by the first occurrence of a character for which @a pred is @c true.
   template <typename F> self_type &remove_prefix_if(F const &pred);
 
   /** Split a prefix from the view on the character at offset @a n.
@@ -391,10 +391,10 @@ public:
   /// Overload to provide better return type.
   self_type &remove_suffix(size_t n);
 
-  /// Remove a suffix, delimited by the last occurence of @c c.
+  /// Remove a suffix, delimited by the last occurrence of @c c.
   self_type &remove_suffix_at(char c);
 
-  /// Remove a suffix, delimited by the last occurence of a character for which @a pred is @c true.
+  /// Remove a suffix, delimited by the last occurrence of a character for which @a pred is @c true.
   template <typename F> self_type &remove_suffix_if(F const &f);
 
   /** Split the view to get a suffix of size @a n.
diff --git a/include/wccp/Wccp.h b/include/wccp/Wccp.h
index 40dff8f..ec1424c 100644
--- a/include/wccp/Wccp.h
+++ b/include/wccp/Wccp.h
@@ -255,7 +255,7 @@ public:
   /// Perform house keeping, including sending outbound messages.
   int housekeeping();
 
-  /// Recieve and process a message on the socket.
+  /// Receive and process a message on the socket.
   /// @return 0 for success, -ERRNO on system error.
   ts::Rv<int> handleMessage();
diff --git a/include/ts/remap.h b/include/ts/remap.h
index edc1c23..cc263fd 100644
--- a/include/ts/remap.h
+++ b/include/ts/remap.h
@@ -43,7 +43,7 @@ typedef struct _tsremap_api_info {
 typedef struct _tm_remap_request_info {
   /* Important: You should *not* release these buf pointers or TSMLocs from your plugin! */
 
-  /* these URL mloc's are read only, use normal ts/ts.h APIs for accesing  */
+  /* these URL mloc's are read only, use normal ts/ts.h APIs for accessing  */
   TSMLoc mapFromUrl;
   TSMLoc mapToUrl;
 
@@ -61,7 +61,7 @@ typedef struct _tm_remap_request_info {
 
 /* This is the type returned by the TSRemapDoRemap() callback */
 typedef enum {
-  TSREMAP_NO_REMAP       = 0, /* No remaping was done, continue with next in chain */
+  TSREMAP_NO_REMAP       = 0, /* No remapping was done, continue with next in chain */
   TSREMAP_DID_REMAP      = 1, /* Remapping was done, continue with next in chain */
   TSREMAP_NO_REMAP_STOP  = 2, /* No remapping was done, and stop plugin chain evaluation */
   TSREMAP_DID_REMAP_STOP = 3, /* Remapping was done, but stop plugin chain evaluation */
@@ -88,7 +88,7 @@ typedef enum {
 */
 tsapi TSReturnCode TSRemapInit(TSRemapInterface *api_info, char *errbuf, int errbuf_size);
 
-/* This gets called everytime remap.config is reloaded. This is complementary
+/* This gets called every time remap.config is reloaded. This is complementary
    to TSRemapInit() which gets called when the plugin is first loaded. You can
    not fail, or cause reload to stop here, it's merely a notification.
    Optional function.
@@ -99,7 +99,7 @@ tsapi void TSRemapConfigReload(void);
 /* Remap new request
    Mandatory interface function.
    Remap API plugin can/should use SDK API function calls inside this function!
-   return: TSREMAP_NO_REMAP - No remaping was done, continue with next in chain
+   return: TSREMAP_NO_REMAP - No remapping was done, continue with next in chain
            TSREMAP_DID_REMAP - Remapping was done, continue with next in chain
            TSREMAP_NO_REMAP_STOP - No remapping was done, and stop plugin chain evaluation
            TSREMAP_DID_REMAP_STOP -  Remapping was done, but stop plugin chain evaluation
@@ -113,7 +113,7 @@ tsapi void TSRemapDone(void);
 /* Plugin new instance. Create new plugin processing entry for unique remap record.
    First two arguments in argv vector are - fromURL and toURL from remap record.
    Please keep in mind that fromURL and toURL will be converted to canonical view.
-   Return: TS_SUCESS
+   Return: TS_SUCCESS
            TS_ERROR - instance creation error
 */
 tsapi TSReturnCode TSRemapNewInstance(int argc, char *argv[], void **ih, char *errbuf, int errbuf_size);